<?php
/**
 * This file adds the account page and starts the render process.
 *
 * @package    Nelio_AB_Testing
 * @subpackage Nelio_AB_Testing/admin/pages
 * @author     David Aguilera <david.aguilera@neliosoftware.com>
 * @since      5.0.0
 */

defined( 'ABSPATH' ) || exit;

/**
 * Class that adds the account page.
 */
class Nelio_AB_Testing_Account_Page extends Nelio_AB_Testing_Abstract_Page {

	public function __construct() {

		if ( nab_is_subscribed() ) {
			$menu = _x( 'Account', 'text', 'nelio-ab-testing' );
			$page = _x( 'Account Details', 'text', 'nelio-ab-testing' );
		} else {
			$menu = _x( 'Premium', 'text', 'nelio-ab-testing' );
			$page = _x( 'Upgrade to Nelio A/B Testing Premium', 'user', 'nelio-ab-testing' );
		}//end if

		parent::__construct(
			'nelio-ab-testing',
			$page,
			$menu,
			'manage_options',
			'nelio-ab-testing-account'
		);

	}//end __construct()

	// @Implements
	public function enqueue_assets() {

		$script = <<<JS
		( function() {
			wp.domReady( function() {
				nab.initPage( "account", %s );
			} );
		} )();
JS;

		$settings = array(
			'siteId'       => nab_get_site_id(),
			'subscription' => nab_get_subscription(),
			'help'         => [],
		);

		if ( nab_is_subscribed() ) {
			$settings['help'] = array(
				array(
					'label' => _x( 'How do I change my payment details?', 'text', 'nelio-ab-testing' ),
					'link'  => _x( 'https://neliosoftware.com/testing/help/how-do-i-change-my-payment-details/', 'text', 'nelio-ab-testing' ),
				),
				array(
					'label' => _x( 'What if my monthly quota of page views gets exhausted?', 'text', 'nelio-ab-testing' ),
					'link'  => _x( 'https://neliosoftware.com/testing/help/what-if-my-monthly-quota-gets-exhausted/', 'text', 'nelio-ab-testing' ),
				),
			);
		}//end if

		wp_enqueue_style(
			'nab-account-page',
			nelioab()->plugin_url . '/assets/dist/css/account-page.css',
			[ 'nab-components' ],
			nelioab()->plugin_version
		);
		nab_enqueue_script_with_auto_deps( 'nab-account-page', 'account-page', true );

		wp_add_inline_script(
			'nab-account-page',
			sprintf(
				$script,
				wp_json_encode( $settings ) // phpcs:ignore
			)
		);

	}//end enqueue_assets()

	// @Implements
	public function display() {
		$title = $this->page_title;
		include nelioab()->plugin_path . '/admin/views/nelio-ab-testing-account-page.php';
	}//end display()

}//end class
